@@ -18,7 +18,6 @@ from builtins import str as text
 import bs4
 import markdown
 import semver
-import six
 
 import splunk_appinspect
 import splunk_appinspect.infra
@@ -650,10 +649,7 @@ class Check(object):
             Boolean - True if splunk instance is needed, False if is NOT needed
         """
         # TODO: tests needed
-        if six.PY2:
-            spec = inspect.getargspec(self.fun)  # pylint: disable=W1505
-        else:
-            spec = inspect.getfullargspec(self.fun)
+        spec = inspect.getfullargspec(self.fun)
         if "cluster" in spec.args:
             return True
 
@@ -668,10 +664,7 @@ class Check(object):
                 needed
         """
         # TODO: tests needed
-        if six.PY2:
-            spec = inspect.getargspec(self.fun)  # pylint: disable=W1505
-        else:
-            spec = inspect.getfullargspec(self.fun)
+        spec = inspect.getfullargspec(self.fun)
         if "standalone" in spec.args:
             return True
 
@@ -894,12 +887,7 @@ class Check(object):
             available_args["reporter"] = reporter
 
             args = []
-            if six.PY2:
-                function_arguments = inspect.getargspec(
-                    self.fun
-                ).args  # pylint: disable=W1505
-            else:
-                function_arguments = inspect.getfullargspec(self.fun).args
+            function_arguments = inspect.getfullargspec(self.fun).args
             for arg in function_arguments:
                 if arg in available_args:
                     val = available_args[arg]
