@@ -9,10 +9,9 @@ Custom visualizations are defined in **/default/visualizations.conf** file. For
 import logging
 import os
 import re
+from urllib.parse import unquote
 
 import bs4
-from six import iteritems
-from six.moves.urllib.parse import unquote
 
 import splunk_appinspect
 from splunk_appinspect.configuration_file import NoOptionError
@@ -471,7 +470,7 @@ def check_for_formatter_html_inappropriate_attributes(app, reporter):
 
                     for tag in soup.find_all():
                         tag_name = tag.name.lower() if tag.name else "".lower()
-                        for attr_name, attr_val in iteritems(tag.attrs):
+                        for attr_name, attr_val in iter(tag.attrs.items()):
                             attr_str = f'{attr_name}="{attr_val}"'
                             if attr_name.lower().find("on") == 0:
                                 reporter_output = (
@@ -688,7 +687,9 @@ def check_for_default_values_for_modviz(app, reporter):
                         "default"
                     ):  # property is not defined in the default section of savedsearches.conf.spec
                         return
-                    spec_settings = iteritems(spec_file.get_section("default").options)
+                    spec_settings = iter(
+                        spec_file.get_section("default").options.items()
+                    )
                     modviz_options = [
                         (k, v.lineno)
                         for k, v in spec_settings
