@@ -107,7 +107,7 @@ def check_hotlinking_splunk_web_libraries(app, reporter):
     util.communicate_bad_import_message(reporter, file_list)
 
 
-""" This function throws a warning message during app inspect if the app has HTML dashboards
+""" This function fails if the app has HTML dashboards
 
 @param:
 app: An app object
@@ -119,9 +119,13 @@ reporter: Reporter object """
 def check_html_dashboards(app, reporter):
     """Check for HTML dashboards, which are deprecated."""
 
-    html_dashboard_files = list(
+    default_files = list(
         app.get_filepaths_of_files(basedir="default/data/ui/html", types=[".html"])
     )
+    local_files = list(
+        app.get_filepaths_of_files(basedir="local/data/ui/html", types=[".html"])
+    )
+    html_dashboard_files = default_files + local_files
     message = (
         "Your app includes HTML dashboard files in the data/ui/html directory, "
         "which must be removed. For more information about updating dashboards, see "
@@ -129,4 +133,4 @@ def check_html_dashboards(app, reporter):
     )
 
     for relative_filepath, _ in html_dashboard_files:
-        reporter.warn(message, relative_filepath)
+        reporter.fail(message, relative_filepath)
