@@ -1,3 +1,2 @@
 """ This module defines classes for implementing HTTP applications """
-from . import server
-from . import client
\ No newline at end of file
+from . import client, server  # noqa: F401
