@@ -1,3 +1,2 @@
 """Remote Procedure Call method that uses XML passed via HTTP(S) as a transport"""
-from . import server
-from . import client
\ No newline at end of file
+from . import client, server  # noqa: F401
